# Generated by Django 2.0.7 on 2018-07-25 18:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('small_small_hr', '0003_staffdocument_public'),
    ]

    operations = [
        migrations.AlterField(
            model_name='staffprofile',
            name='birthday',
            field=models.DateField(
                blank=True, default=None, null=True, verbose_name='Birthday'),
        ),
    ]
