{{ object.content_object.staff.get_name }},<br /><br />
Your time off request for {{ object.content_object.day_count }} days of {{ object.content_object.get_leave_type_display }} from {{ object.content_object.start|date:"d M" }} - {{ object.content_object.end|date:"d M" }} has been {{ object.content_object.get_review_status_display|lower }}.<br /><br />
{{ object.content_object.start|date:"D, d M Y" }} - {{ object.content_object.end|date:"D, d M Y" }}<br />
{{ object.content_object.get_leave_type_display}}<br />
{{ object.content_object.day_count }} days<br />
Status: {{ object.content_object.get_review_status_display }}
<br/><br/>
Thank you,<br/>
{{SITE.name}}<br/>
------<br/>
http://{{SITE.domain}}
