# Generated by Django 2.0.7 on 2018-07-25 16:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('small_small_hr', '0002_auto_20180722_1808'),
    ]

    operations = [
        migrations.AddField(
            model_name='staffdocument',
            name='public',
            field=models.BooleanField(
                default=False,
                help_text='If public, it will be available to everyone.',
                verbose_name='Public'),
        ),
    ]
