# Generated by Django 3.0.7 on 2020-06-26 10:13
# pylint: disable=invalid-name,missing-module-docstring,missing-class-docstring
import django.db.models.deletion
from django.db import migrations

import mptt.fields


class Migration(migrations.Migration):

    dependencies = [
        ("small_small_hr", "0009_auto_20200607_2244"),
    ]

    operations = [
        migrations.AlterField(
            model_name="staffprofile",
            name="supervisor",
            field=mptt.fields.TreeForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="children",
                to="small_small_hr.StaffProfile",
                verbose_name="Manager",
            ),
        ),
    ]
