"""Main init file for small_small_hr."""
VERSION = (0, 4, 2)
__version__ = ".".join(str(v) for v in VERSION)
# pylint: disable=invalid-name
default_app_config = "small_small_hr.apps.SmallSmallHrConfig"  # noqa
