{{ object.content_object.staff.get_name }} requested time off:<br /><br />
{{ object.content_object.day_count }} days of {{ object.content_object.get_leave_type_display}}<br />
{{ object.content_object.start|date:"D, d M Y" }} - {{ object.content_object.end|date:"D, d M Y" }}<br />
Available Balance: {{ object.content_object.staff.get_available_leave_days|floatformat:2 }} days<br /><br />
Please log in to process the above: http://{{SITE.domain}}/reviews/{{ object.pk }}
<br/><br/>
Thank you,<br/>
{{SITE.name}}<br/>
------<br/>
http://{{SITE.domain}}
