"""Constants."""
HOURS = "hours"
MINUTES = "minutes"
STAFF = "staff"
OVERTIME_APPLICATION_EMAIL_TEMPLATE = "overtime_application"
OVERTIME_COMPLETED_EMAIL_TEMPLATE = "overtime_completed"
LEAVE_APPLICATION_EMAIL_TEMPLATE = "leave_application"
LEAVE_COMPLETED_EMAIL_TEMPLATE = "leave_completed"
EMAIL_TEMPLATE_PATH = "small_small_hr/email"
