# Generated by Django 2.1.3 on 2018-12-08 22:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('small_small_hr', '0005_auto_20181115_2112'),
    ]

    operations = [
        migrations.CreateModel(
            name='FreeDay',
            fields=[
                ('id',
                 models.AutoField(
                     auto_created=True,
                     primary_key=True,
                     serialize=False,
                     verbose_name='ID')),
                ('name', models.CharField(max_length=255,
                                          verbose_name='Name')),
                ('date', models.DateField(unique=True, verbose_name='Date')),
            ],
            options={
                'verbose_name': 'Free Day',
                'verbose_name_plural': 'Free Days',
                'ordering': ['-date'],
            },
        ),
        migrations.AlterModelOptions(
            name='annualleave',
            options={
                'ordering': ['-year', 'leave_type', 'staff'],
                'verbose_name': 'Annual Leave',
                'verbose_name_plural': 'Annual Leave'
            },
        ),
        migrations.AlterModelOptions(
            name='leave',
            options={
                'ordering': ['staff', '-start'],
                'verbose_name': 'Leave',
                'verbose_name_plural': 'Leave'
            },
        ),
        migrations.AlterModelOptions(
            name='overtime',
            options={
                'ordering': ['staff', '-date', 'start'],
                'verbose_name': 'Overtime',
                'verbose_name_plural': 'Overtime'
            },
        ),
        migrations.AlterModelOptions(
            name='staffdocument',
            options={
                'ordering': ['staff', 'name', '-created'],
                'verbose_name': 'Staff Document',
                'verbose_name_plural': 'Staff Documents'
            },
        ),
        migrations.AlterField(
            model_name='annualleave',
            name='year',
            field=models.PositiveIntegerField(
                choices=[(2017, 2017), (2018, 2018), (2019, 2019), (2020,
                                                                    2020),
                         (2021, 2021), (2022, 2022), (2023, 2023), (2024,
                                                                    2024),
                         (2025, 2025), (2026, 2026), (2027, 2027)],
                db_index=True,
                default=2018,
                verbose_name='Year'),
        ),
    ]
